{
    "$graph": [
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/altanalyze:v0.0.6"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "#!/bin/bash\n\n# Copy altanalyze to the current working directory\n# which is mount with -rw- permissions. Otherwise \n# we can't download anything because by default\n# container is run by cwltool with --read-only\n\ncp -r /opt/altanalyze .\n\nGENOME_TYPE=$0\ncase ${GENOME_TYPE} in\n  mm10)\n    SPECIES=Mm\n    # ENSEMBL_VERSION=EnsMart69\n    ENSEMBL_VERSION=EnsMart72\n    ;;\n  hg19)\n    SPECIES=Hs\n    # ENSEMBL_VERSION=EnsMart62\n    ENSEMBL_VERSION=EnsMart72\n    ;;\n  hg38)\n    SPECIES=Hs\n    # ENSEMBL_VERSION=EnsMart78\n    ENSEMBL_VERSION=EnsMart72\n    ;;\n  *)\n    echo \"Unknown genome\"\n    exit 1\n    ;;\nesac\necho \"Selected ${SPECIES} and ${ENSEMBL_VERSION}\"\npython ./altanalyze/AltAnalyze.py --species ${SPECIES} --update Official --version ${ENSEMBL_VERSION}\nmkdir genome_data\nmv ./altanalyze/AltDatabase/EnsMart* ./genome_data/${ENSEMBL_VERSION}__${SPECIES}\necho \"Remove files with ' in the name as we can't mount them to container anyway\"\ncd ./genome_data/${ENSEMBL_VERSION}__${SPECIES}\ndu -a | grep \"'\" | cut -f 2 | awk '{print \"\\\"\"$1\"\\\"\"}' | xargs rm -f\n",
                    "inputBinding": {
                        "position": 5
                    },
                    "doc": "Bash script to select proper parameters for AltAnalyze based on the genome value\n",
                    "id": "#altanalyze-prepare-genome.cwl/bash_script"
                },
                {
                    "type": {
                        "type": "enum",
                        "symbols": [
                            "#altanalyze-prepare-genome.cwl/genome/mm10",
                            "#altanalyze-prepare-genome.cwl/genome/hg19",
                            "#altanalyze-prepare-genome.cwl/genome/hg38"
                        ],
                        "inputBinding": {
                            "position": 6
                        }
                    },
                    "doc": "Genome type, such as mm10, hg19 or hg38. Based on the selected value we will set\n--species and --version parameters.\n",
                    "id": "#altanalyze-prepare-genome.cwl/genome"
                }
            ],
            "baseCommand": [
                "bash",
                "-c"
            ],
            "stdout": "altanalyze_prepare_genome_stdout.log",
            "stderr": "altanalyze_prepare_genome_stderr.log",
            "doc": "Downloads data from the Ensembl Database based on the selected genome.\nOutput folder name will be always equal to ENSEMBL_VERSION__SPECIES.\n\nAltAnalyze has problems downloading EnsMart69 and EnsMart78, so only hg19\ngenome is currently supported.\n",
            "id": "#altanalyze-prepare-genome.cwl",
            "http://schema.org/name": "altanalyze-prepare-genome",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/altanalyze-prepare-genome.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "id": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                },
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Salomonis Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Stuart Hay",
                                            "http://schema.org/email": "mailto:haysb91@gmail.com"
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "EnsMart72 has GRCh37.p11, GRCm38.p1 and no GRCh38, which is not good for us.\n\nEnsMart69 has original version of GRCm38. The same we use for our mm10 pipelines.\nEnsMart62 has original version of GRCh37. The same we use for our hg19 pipelines.\nEnsMart78 has original version of GRCh38. The same we use for our hg38 pipelines.\n\nFor reference:\nhttp://useast.ensembl.org/info/website/archives/assembly.html\nhttps://m.ensembl.org/Help/Faq?id=286\n",
            "outputs": [
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "genome_data/*"
                    },
                    "id": "#altanalyze-prepare-genome.cwl/genome_data"
                },
                {
                    "type": "File",
                    "id": "#altanalyze-prepare-genome.cwl/stderr_log",
                    "outputBinding": {
                        "glob": "altanalyze_prepare_genome_stderr.log"
                    }
                },
                {
                    "type": "File",
                    "id": "#altanalyze-prepare-genome.cwl/stdout_log",
                    "outputBinding": {
                        "glob": "altanalyze_prepare_genome_stdout.log"
                    }
                }
            ]
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "label": "Experiment short name/Alias",
                    "sd:preview": {
                        "position": 1
                    },
                    "id": "#main/alias"
                },
                {
                    "type": {
                        "type": "enum",
                        "symbols": [
                            "#main/genome/mm10",
                            "#main/genome/hg19",
                            "#main/genome/hg38"
                        ]
                    },
                    "label": "Genome type",
                    "doc": "Genome type, such as mm10, hg19, hg38, etc",
                    "id": "#main/genome"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/altanalyze_prepare_genome/stderr_log",
                    "label": "stderr log generated by altanalyze prepare genome",
                    "doc": "stderr log generated by altanalyze prepare genome\n",
                    "id": "#main/altanalyze_prepare_genome_stderr_log"
                },
                {
                    "type": "File",
                    "outputSource": "#main/altanalyze_prepare_genome/stdout_log",
                    "label": "stdout log generated by altanalyze prepare genome",
                    "doc": "stdout log generated by altanalyze prepare genome\n",
                    "id": "#main/altanalyze_prepare_genome_stdout_log"
                },
                {
                    "type": "Directory",
                    "outputSource": "#main/altanalyze_prepare_genome/genome_data",
                    "label": "AltAnalyze genome data",
                    "doc": "Pre-downloaded Ensembl database for the specific genome\n",
                    "id": "#main/genome_data"
                }
            ],
            "steps": [
                {
                    "run": "#altanalyze-prepare-genome.cwl",
                    "in": [
                        {
                            "source": "#main/genome",
                            "id": "#main/altanalyze_prepare_genome/genome"
                        }
                    ],
                    "out": [
                        "#main/altanalyze_prepare_genome/genome_data",
                        "#main/altanalyze_prepare_genome/stdout_log",
                        "#main/altanalyze_prepare_genome/stderr_log"
                    ],
                    "id": "#main/altanalyze_prepare_genome"
                }
            ],
            "label": "AltAnalyze Build Reference Indices",
            "doc": "AltAnalyze Build Reference Indices\n==================================",
            "id": "#main",
            "http://schema.org/name": "AltAnalyze Build Reference Indices",
            "http://schema.org/alternateName": "Builds reference genome indices for AltAnalyze ICGS and AltAnalyze CellHarmony experiments",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/datirium/workflows/master/workflows/altanalyze-prepare-genome.cwl",
            "http://schema.org/codeRepository": "https://github.com/datirium/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ]
        }
    ],
    "cwlVersion": "v1.0",
    "$schemas": [
        "https://github.com/schemaorg/schemaorg/raw/main/data/releases/11.01/schemaorg-current-http.rdf"
    ],
    "$namespaces": {
        "s": "http://schema.org/"
    }
}
